
########################################################################################
########## Data generation script for:
##########
########## Marco Del Giudice & Steven W. Gangestad (2020).
########## A Traveler’s Guide to the Multiverse: 
########## Promises, Pitfalls, and a Framework for the Evaluation of Analytic Decisions.
########## Advances in Methods and Practices in Psychological Science.
##########
########## This file contains the simulation parameters and the function used to 
########## generate simulated datasets (generate.dataset)
########################################################################################


############################################################
########## 1. graphical device check for Windows
############################################################

if(.Platform$OS.type=="windows") {
  quartz<-function() windows()
} 


############################################################
########## 2. Simulation parameters
############################################################

sample_size = 300
n_extreme_values = 3
beta_inflammation_depression = 0.2
beta_inflammation_BM1 = 0.6
beta_inflammation_BM2 = 0.6
beta_inflammation_BM3 = 0.6
beta_inflammation_BM4 = 0.2
beta_genotype_inflammation = 0.5
beta_age_inflammation = 0.4
beta_age_depression = -0.3
beta_inflammation_fatigue = 0.3
beta_depression_fatigue = 0.6
beta_age_fatigue = 0.2
beta_pain_fatigue = 0.1
beta_inflammation_pain = 0.3
beta_pain_depression = 0.3


############################################################
########## 3. Data generation function
############################################################

generate.dataset <- function() {
	genotype = rnorm(sample_size)
	
	age = rnorm(sample_size)
	
	inflammation = genotype*beta_genotype_inflammation + age*beta_age_inflammation + rnorm(sample_size, sd=sqrt(1-(beta_genotype_inflammation^2+beta_age_inflammation^2)))
	
	pain = inflammation*beta_inflammation_pain + rnorm(sample_size, sd=sqrt(1-beta_inflammation_pain^2))
	
	depression = inflammation*beta_inflammation_depression + age*beta_age_depression + pain*beta_pain_depression + rnorm(sample_size, sd=sqrt(1-(beta_inflammation_depression^2+beta_age_depression^2+beta_pain_depression^2)))
	
	BM1 = inflammation*beta_inflammation_BM1 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM1^2))
	BM2 = inflammation*beta_inflammation_BM2 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM2^2))
	BM3 = inflammation*beta_inflammation_BM3 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM3^2))
	BM4 = inflammation*beta_inflammation_BM4 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM4^2))
	
	fatigue = inflammation*beta_inflammation_fatigue + depression*beta_depression_fatigue + age*beta_age_fatigue + pain*beta_pain_fatigue + rnorm(sample_size, sd=sqrt(1-(beta_inflammation_fatigue^2+beta_depression_fatigue^2+beta_age_fatigue^2+beta_pain_fatigue^2)))
	
	# add extreme values to biomarker variables
	
	BM1[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM2[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM3[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM4[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)

	return(data.frame(age, genotype, BM1, BM2, BM3, BM4, depression, pain, fatigue))
}


############################################################
########## 4. Generate a dataset
############################################################

dataset = generate.dataset()
