
########################################################################################
########## Main analysis script for:
##########
########## Marco Del Giudice & Steven W. Gangestad (2020).
########## A Traveler’s Guide to the Multiverse: 
########## Promises, Pitfalls, and a Framework for the Evaluation of Analytic Decisions.
########## Advances in Methods and Practices in Psychological Science.
##########
########## This file contains the R script for the main analysis reported in the paper,
########## based on the simulated dataset "multiverse_main_dataset.csv". 
########################################################################################


library(MASS)
library(lm.beta)
library(tibble)
library(specr)  # https://github.com/masurp/specr/ 
library(ggplot2)
library(cowplot)


############################################################
########## 1. Graphical device check for Windows
############################################################

if(.Platform$OS.type=="windows") {
  quartz<-function() windows()
} 


############################################################
########## 2. Load dataset
############################################################

dataset = read.csv("multiverse_main_dataset.csv")[,-1]


############################################################
########## 3. Full multiverse: analyses
############################################################

##### Standard deviations and Tukey's fences (for outlier cutoffs)

sd.BM1 = sd(dataset$BM1)
sd.BM2 = sd(dataset$BM2)
sd.BM3 = sd(dataset$BM3)
sd.BM4 = sd(dataset$BM4)

Tukey.lower.BM1 = quantile(dataset$BM1, probs=0.25)-1.5*(quantile(dataset$BM1, probs=0.75)-quantile(dataset$BM1, probs=0.25)) 
Tukey.upper.BM1 = quantile(dataset$BM1, probs=0.75)+1.5*(quantile(dataset$BM1, probs=0.75)-quantile(dataset$BM1, probs=0.25))
Tukey.lower.BM2 = quantile(dataset$BM2, probs=0.25)-1.5*(quantile(dataset$BM2, probs=0.75)-quantile(dataset$BM2, probs=0.25))
Tukey.upper.BM2 = quantile(dataset$BM2, probs=0.75)+1.5*(quantile(dataset$BM2, probs=0.75)-quantile(dataset$BM2, probs=0.25))
Tukey.lower.BM3 = quantile(dataset$BM3, probs=0.25)-1.5*(quantile(dataset$BM3, probs=0.75)-quantile(dataset$BM3, probs=0.25))
Tukey.upper.BM3 = quantile(dataset$BM3, probs=0.75)+1.5*(quantile(dataset$BM3, probs=0.75)-quantile(dataset$BM3, probs=0.25))
Tukey.lower.BM4 = quantile(dataset$BM4, probs=0.25)-1.5*(quantile(dataset$BM4, probs=0.75)-quantile(dataset$BM4, probs=0.25))
Tukey.upper.BM4 = quantile(dataset$BM4, probs=0.75)+1.5*(quantile(dataset$BM4, probs=0.75)-quantile(dataset$BM4, probs=0.25))

##### Calculate p-values and effect sizes (regression beta)

p_values = rep(NA, 1216) # vector of p-values
betas = rep(NA, 1216) # vector of effect sizes
conf.low = rep(NA, 1216) # vector of lower confidence bounds
conf.high = rep(NA, 1216) # vector of higher confidence bounds
ns = rep(NA, 1216) # vector of sample sizes
x = rep("", 1216) # vector of labels for alternative predictor specifications
controls = rep("", 1216) # vector of labels for covariates
model = rep("", 1216) # vector of labels for alternative outlier cutoffs


index = 1 # vector location index 

for (predictor in 1:19) {
	for (covariates in 1:16) {
		for (outliers in 1:4)
		{
			model_formula = "data$depression ~ data$pred"  # regression formula to be passed to lm()
			
			# decision node: alternative cutoffs for outliers
			
			if (outliers == 1) {
				data = dataset
				model[index] = "d  All cases"
				}
			else if (outliers == 2) {
				data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,]
				model[index] = "c  Quartiles +/- 1.5 IQR"
				}
			else if (outliers == 3) {
				data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
				model[index] = "b  Mean +/- 2.5 SD"
				}
			else if (outliers == 4) {
				data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
				model[index] = "a  Mean +/- 3.5 SD"
				}
			
			ns[index] = nrow(data)  # save sample size after outlier exclusion
			
			# decision node: alternative predictors
			
			if (predictor == 1) {
				data$pred = data$BM1
				x[index] = "s  Biomarker BM1"
				}
			else if (predictor == 2) {
				data$pred = data$BM2
				x[index] = "r  Biomarker BM2"
				}
			else if (predictor == 3) {
				data$pred = data$BM3
				x[index] = "q  Biomarker BM3"
				}
			else if (predictor == 4) {
				data$pred = data$BM4
				x[index] = "p  Biomarker BM4"
				}
			else if (predictor == 5) {
				data$pred = data$BM1
				x[index] = "o  BM1, other biomarkers controlled"
				model_formula = paste(model_formula, "+ data$BM2 + data$BM3 + data$BM4")
				}
			else if (predictor == 6) {
				data$pred = data$BM2
				x[index] = "n  BM2, other biomarkers controlled"
				model_formula = paste(model_formula, "+ data$BM1 + data$BM3 + data$BM4")
				}
			else if (predictor == 7) {
				data$pred = data$BM3
				x[index] = "m  BM3, other biomarkers controlled"
				model_formula = paste(model_formula, "+ data$BM1 + data$BM2 + data$BM4")
				}
			else if (predictor == 8) {
				data$pred = data$BM4
				x[index] = "l  BM4, other biomarkers controlled"
				model_formula = paste(model_formula, "+ data$BM1 + data$BM2 + data$BM3")
				}
			else if (predictor == 9) {
				data$pred = data$BM1+data$BM2
				x[index] = "k  BM1+BM2 composite"
				}
			else if (predictor == 10) {
				data$pred = data$BM1+data$BM3
				x[index] = "j  BM1+BM3 composite"
				}
			else if (predictor == 11) {
				data$pred = data$BM1+data$BM4
				x[index] = "i  BM1+BM4 composite"
				}
			else if (predictor == 12) {
				data$pred = data$BM2+data$BM3
				x[index] = "h  BM2+BM3 composite"
				}
			else if (predictor == 13) {
				data$pred = data$BM2+data$BM4
				x[index] = "g  BM2+BM4 composite"
				}
			else if (predictor == 14) {
				data$pred = data$BM3+data$BM4
				x[index] = "f  BM3+BM4 composite"
				}
			else if (predictor == 15) {
				data$pred = data$BM1+data$BM2+data$BM3
				x[index] = "e  BM1+BM2+BM3 composite"
				}
			else if (predictor == 16) {
				data$pred = data$BM1+data$BM2+data$BM4
				x[index] = "d  BM1+BM2+BM4 composite"
				}
			else if (predictor == 17) {
				data$pred = data$BM1+data$BM3+data$BM4
				x[index] = "c  BM1+BM3+BM4 composite"
				}
			else if (predictor == 18) {
				data$pred = data$BM2+data$BM3+data$BM4
				x[index] = "b  BM2+BM3+BM4 composite"
				}
			else if (predictor == 19) {
				data$pred = data$BM1+data$BM2+data$BM3+data$BM4
				x[index] = "a  BM1+BM2+BM3+BM4 composite"
				}
			
			# decision node: alternative covariate sets
			
			if (covariates == 1) {
				controls[index] = "p  No covariates"			
				}
			else if (covariates == 2) {
				model_formula = paste(model_formula, "+ data$fatigue")
				controls[index] = "m  Fatigue"
				}
			else if (covariates == 3) {
				model_formula = paste(model_formula, "+ data$pain")
				controls[index] = "n  Pain"
				}
			else if (covariates == 4) {
				model_formula = paste(model_formula, "+ data$pain + data$fatigue")
				controls[index] = "h  Pain, fatigue"
				}
			else if (covariates == 5) {
				model_formula = paste(model_formula, "+ data$age")
				controls[index] = "o  Age"
				}
			else if (covariates == 6) {
				model_formula = paste(model_formula, "+ data$fatigue + data$age")
				controls[index] = "j  Age, fatigue"
				}
			else if (covariates == 7) {
				model_formula = paste(model_formula, "+ data$pain + data$age")
				controls[index] = "k  Age, pain"
				}
			else if (covariates == 8) {
				model_formula = paste(model_formula, "+ data$fatigue + data$pain + data$age")
				controls[index] = "e  Age, pain, fatigue"
				}
			else if (covariates == 9) {
				model_formula = paste(model_formula, "+ data$genotype")
				controls[index] = "l  Genotype"
				}
			else if (covariates == 10) {
				model_formula = paste(model_formula, "+ data$genotype + data$fatigue")
				controls[index] = "f  Fatigue, genotype"
				}
			else if (covariates == 11) {
				model_formula = paste(model_formula, "+ data$genotype + data$pain")
				controls[index] = "g  Pain, genotype"
				}
			else if (covariates == 12) {
				model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$pain")
				controls[index] = "b  Pain, fatigue, genotype"
				}
			else if (covariates == 13) {
				model_formula = paste(model_formula, "+ data$genotype + data$age")
				controls[index] = "i  Age, genotype"
				}
			else if (covariates == 14) {
				model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$age")
				controls[index] = "c  Age, fatigue, genotype"
				}
			else if (covariates == 15) {
				model_formula = paste(model_formula, " + data$genotype+ data$pain + data$age")
				controls[index] = "d  Age, pain, genotype"
				}
			else if (covariates == 16) {
				model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$pain + data$age")
				controls[index] = "a  Age, pain, fatigue, genotype"
				}
			
			# regression fit
			
			standardized.model = lm.beta(lm(as.formula(model_formula)))
			
			# save beta, p-value, confidence intervals for the predictor
			
			betas[index] = summary(standardized.model)$coefficients[2,2]
			p_values[index] = summary(standardized.model)$coefficients[2,5]
			conf.low[index] = confint(standardized.model)[2,1]
			conf.high[index] = confint(standardized.model)[2,2]
			
			# increment location index for p-values and effect sizes
			
			index = index + 1
		}
	}
}

##### Summary statistics

quantile(p_values, probs=0.5)
prop_signif_05 = sum(p_values<.05)/length(p_values) # proportion of p-values < .05
RP = -log10(as.numeric(quantile(p_values, probs=0.01))) + log10(as.numeric(quantile(p_values, probs=0.99))) # relative p-value (Patel et al., 2015)
prop_signif_05
RP

min(betas)
mean(betas)
max(betas)
quantile(betas, probs=0.01)
quantile(betas, probs=0.50)
quantile(betas, probs=0.99)

unique(ns) # sample size at different cutoffs

##### Build tibble for specification curve

spec_curve = tibble(estimate = betas, p.value = p_values, conf.low, conf.high, controls, model, x, y = rep(0, 1216), subsets = rep(0, 1216))


############################################################
########## 4. Full multiverse: plots
##########
########## (Note: plots require additional clean-up/editing)
############################################################

quartz(width=12, height=5.5)
layout(matrix(c(1:2), 1, 2), widths=c(30,23))

##### Multiverse plot (p-values)

hist(p_values, xlim=c(0,1), xlab=expression(paste(italic("p"),"-value")), ylab ="Count", breaks = seq(0,1,0.01), col="grey60", border="grey60", yaxt="n", main="", cex.lab=1.35, cex.axis=1.2)
axis(2, at=c(0,20,40,60,80,100,120), las=1, cex.axis=1.2)
abline(v=0.05, lty=3, col="red", lwd=1.5)
text(0.05, 100, expression(paste(italic(p)," = .05")), pos=4, col="red", cex=1.2)

##### Vibration of effects plot (effect sizes vs. p-values)

point.color = rgb(100,100,100, alpha=80, maxColorValue=255)
contour.color = rgb(60,130,180, alpha=130, maxColorValue=255)

z = kde2d(betas, -log10(p_values), n=50)

plot(betas, -log10(p_values), type="n", las=1, xlab=expression(paste("Effect size (", beta, ")")), ylab=expression(paste("-log"[10],"(",italic("p"),"-value)")), cex.lab=1.35, cex.axis=1.2)
abline(v=as.numeric(quantile(betas, probs=0.01)), lty=3, lwd=1.8, col="gray70")
abline(v=as.numeric(quantile(betas, probs=0.5)), lty=3, lwd=1.8, col="gray70")
abline(v=as.numeric(quantile(betas, probs=0.99)), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(as.numeric(quantile(p_values, probs=0.01))), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(as.numeric(quantile(p_values, probs=0.5))), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(as.numeric(quantile(p_values, probs=0.99))), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(0.05), lty=3, lwd=1.5, col="red")
points(betas, -log10(p_values), pch=16, col=point.color, cex=0.9)
contour(z, drawlabels=FALSE, nlevels=20, lwd=1.7, col=contour.color, add=TRUE)
text(as.numeric(quantile(betas, probs=0.01)), max(-log10(p_values)), "1", pos=2, col="gray40", cex=1)
text(as.numeric(quantile(betas, probs=0.5)), max(-log10(p_values)), "50", pos=2, col="gray40", cex=1)
text(as.numeric(quantile(betas, probs=0.99)), max(-log10(p_values)), "99", pos=2, col="gray40", cex=1)
text(max(betas), -log10(as.numeric(quantile(p_values, probs=0.01))), "1", pos=3, col="gray40", cex=1)
text(max(betas), -log10(as.numeric(quantile(p_values, probs=0.5))), "50", pos=3, col="gray40", cex=1)
text(max(betas), -log10(as.numeric(quantile(p_values, probs=0.99))), "99", pos=3, col="gray40", cex=1)
text(-0.01, -log10(0.05), expression(paste(italic(p)," = .05")), pos=3, col="red", cex=1.2)

##### Specification curve plot

quartz(width=9, height=10)

p1 <- plot_curve(spec_curve, ci = FALSE, ribbon = FALSE) +
  geom_hline(yintercept = 0, linetype = "dashed", color = "grey") +
  labs(x = "", y = expression(paste("Effect size (", beta, ")"))) +
  theme_half_open()

p2 <- plot_choices(spec_curve, 
                   choices = c("x", "controls", "model")) +
  labs(x = "Specifications (ranked)") +
  theme_half_open() +
  theme(strip.text.x = element_blank())

plot_specs(plot_a = p1,
           plot_b = p2,
           labels = c("", ""),
           rel_height = c(1, 4))


############################################################
########## 5. Principled muliverse: analyses 
##########
########## Model 1 = controlling for age and pain
########## Model 2 = controlling for age, pain, fatigue
############################################################

##### Calculate p-values and effect sizes (beta): Model 1

p_values_model1 = rep(NA, 6) # vector of p-values
betas_model1 = rep(NA, 6) # vector of effect sizes

index = 1 # vector location index 

for (predictor in 1:2) {
		for (outliers in 1:3)
		{
			model_formula = "data$depression ~ data$pred" # regression formula to be passed to lm()
			
			# alternative cutoffs for outliers
			
			if (outliers == 1) data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,] 
			else if (outliers == 2) data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
			else if (outliers == 3) data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
			
			# alternative predictors
			
			if (predictor == 1) data$pred = data$BM1+data$BM2+data$BM3
			else if (predictor == 2) data$pred = data$BM1+data$BM2+data$BM3+data$BM4
			
			# covariate set
			
			model_formula = paste(model_formula, "+ data$age + data$pain")
			
			# regression model
			
			standardized.model = lm.beta(lm(as.formula(model_formula)))
			
			# beta and p-value for the predictor
			
			betas_model1[index] = summary(standardized.model)$coefficients[2,2]
			p_values_model1[index] = summary(standardized.model)$coefficients[2,5]
			
			# increment location index for p-values and effect sizes
			
			index = index + 1
		}
}

##### Calculate p-values and effect sizes (beta): Model 2

p_values_model2 = rep(NA, 6) # vector of p-values
betas_model2 = rep(NA, 6) # vector of effect sizes

index = 1 # location index for p-values and effect sizes

for (predictor in 1:2) {
		for (outliers in 1:3)
		{
			model_formula = "data$depression ~ data$pred" # regression formula to be passed to lm()
			
			# alternative cutoffs for outliers
			
			if (outliers == 1) data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,] 
			else if (outliers == 2) data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
			else if (outliers == 3) data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
			
			# alternative predictors
			
			if (predictor == 1) data$pred = data$BM1+data$BM2+data$BM3
			else if (predictor == 2) data$pred = data$BM1+data$BM2+data$BM3+data$BM4
			
			# covariate set
			
			model_formula = paste(model_formula, "+ data$age + data$pain + data$fatigue")
			
			# regression model
			
			standardized.model = lm.beta(lm(as.formula(model_formula)))
			
			# beta and p-value for the predictor
			
			betas_model2[index] = summary(standardized.model)$coefficients[2,2]
			p_values_model2[index] = summary(standardized.model)$coefficients[2,5]
			
			# increment location index for p-values and effect sizes
			
			index = index + 1
		}
}

##### Summary statistics

min(betas_model1)
mean(betas_model1)
max(betas_model1)
quantile(betas_model1, probs=0.01)
quantile(betas_model1, probs=0.50)
quantile(betas_model1, probs=0.99)

quantile(p_values_model1, probs=0.5)
prop_signif_05_model1 = sum(p_values_model1<.05)/length(p_values_model1) # proportion of p-values < .05
RP_model1 = -log10(as.numeric(quantile(p_values_model1, probs=0.01))) + log10(as.numeric(quantile(p_values_model1, probs=0.99))) # relative p-value (Patel et al., 2015)
prop_signif_05_model1
RP_model1

min(betas_model2)
mean(betas_model2)
max(betas_model2)
quantile(betas_model2, probs=0.01)
quantile(betas_model2, probs=0.50)
quantile(betas_model2, probs=0.99)

quantile(p_values_model2, probs=0.5)
prop_signif_05_model2 = sum(p_values_model2<.05)/length(p_values_model2) # proportion of p-values < .05
RP_model2 = -log10(as.numeric(quantile(p_values_model2, probs=0.01))) + log10(as.numeric(quantile(p_values_model2, probs=0.99))) # relative p-value (Patel et al., 2015)
prop_signif_05_model2
RP_model2


############################################################
########## 6. Principled multiverse: plots
##########
########## (Note: plots require additional clean-up/editing)
############################################################

##### Multiverse plot (p-values):Model 1

quartz(width=12, height=5.5)
layout(matrix(c(1:2), 1, 2), widths=c(30,23))

hist(p_values_model1, xlim=c(0,1), xlab=expression(paste(italic("p"),"-value")), ylab ="Count", breaks = seq(0,1,0.01), col="grey60", border="grey60", yaxt="n", main="", cex.lab=1.35, cex.axis=1.2)
axis(2, at=c(0,1,2,3), las=1, cex.axis=1.2)
abline(v=0.05, lty=3, col="red", lwd=1.5)
text(0.05, 2.95, expression(paste(italic(p)," = .05")), pos=4, col="red", cex=1.2)

##### Vibration of effects plot (effect sizes vs. p-values): Model 1

point.color = rgb(20,20,20, alpha=150, maxColorValue=255)
contour.color = rgb(60,130,180, alpha=130, maxColorValue=255)

z_model1 = kde2d(betas_model1, -log10(p_values_model1), n=50)

plot(betas_model1, -log10(p_values_model1), type="n", las=1, xlab=expression(paste("Effect size (", beta, ")")), ylab=expression(paste("-log"[10],"(",italic("p"),"-value)")), main="", cex.lab=1.35, cex.axis=1.2 )
abline(v=as.numeric(quantile(betas_model1, probs=0.5)), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(as.numeric(quantile(p_values_model1, probs=0.5))), lty=3, lwd=1.8, col="gray70")
points(betas_model1, -log10(p_values_model1), pch=16, col=point.color, cex=1.5)
contour(z_model1, drawlabels=FALSE, nlevels=5, lwd=1.7, col=contour.color, add=TRUE)
text(as.numeric(quantile(betas_model1, probs=0.5)), max(-log10(p_values_model1)), "50", pos=2, col="gray40", cex=1)
text(max(betas_model1), -log10(as.numeric(quantile(p_values_model1, probs=0.5))), "50", pos=3, col="gray40", cex=1)
abline(h=-log10(0.05), lty=3, lwd=1.5, col="red")

##### Multiverse plot (p-values):Model 2

quartz(width=12, height=5.5)
layout(matrix(c(1:2), 1, 2), widths=c(30,23))

hist(p_values_model2, xlim=c(0,1), xlab=expression(paste(italic("p"),"-value")), ylab ="Count", breaks = seq(0,1,0.01), col="grey60", border="grey60", yaxt="n", main="", cex.lab=1.35, cex.axis=1.2)
axis(2, at=c(0,1,2), las=1, cex.axis=1.2)
abline(v=0.05, lty=3, col="red", lwd=1.5)
text(0.05, 1.95, expression(paste(italic(p)," = .05")), pos=4, col="red", cex=1.2)

##### Vibration of effects plot (effect sizes vs. p-values): Model 2

point.color = rgb(20,20,20, alpha=150, maxColorValue=255)
contour.color = rgb(60,130,180, alpha=130, maxColorValue=255)

z_model2 = kde2d(betas_model2, -log10(p_values_model2), n=50)

plot(betas_model2, -log10(p_values_model2), type="n", las=1, xlab=expression(paste("Effect size (", beta, ")")), ylab=expression(paste("-log"[10],"(",italic("p"),"-value)")), main="", cex.lab=1.35, cex.axis=1.2 )
abline(v=as.numeric(quantile(betas_model2, probs=0.5)), lty=3, lwd=1.8, col="gray70")
abline(h=-log10(as.numeric(quantile(p_values_model2, probs=0.5))), lty=3, lwd=1.8, col="gray70")
points(betas_model2, -log10(p_values_model2), pch=16, col=point.color, cex=1.5)
contour(z_model2, drawlabels=FALSE, nlevels=5, lwd=1.7, col=contour.color, add=TRUE)
text(as.numeric(quantile(betas_model2, probs=0.5)), max(-log10(p_values_model2)), "50", pos=2, col="gray40", cex=1)
text(max(betas_model2), -log10(as.numeric(quantile(p_values_model2, probs=0.5))), "50", pos=3, col="gray40", cex=1)
abline(h=-log10(0.05), lty=3, lwd=1.5, col="red")



