
########################################################################################
########## Replicate analysis script for:
##########
########## Marco Del Giudice & Steven W. Gangestad (2020).
########## A Traveler’s Guide to the Multiverse: 
########## Promises, Pitfalls, and a Framework for the Evaluation of Analytic Decisions.
########## Advances in Methods and Practices in Psychological Science.
##########
########## This file contains the R script used to run repicate analyses as a robustness 
########## check on the main results. The results of the replicate analyses reported in
########## the paper are saved in the file "multiverse_replicate_analyses.csv"
########################################################################################


library(MASS)
library(lm.beta)
library(ggplot2)
library(ggridges)


############################################################
########## 1. Graphical device check for Windows
############################################################

if(.Platform$OS.type=="windows") {
  quartz<-function() windows()
} 


############################################################
########## 2. Simulation parameters
############################################################

n_replicates = 500

sample_size = 300
n_extreme_values = 3
beta_inflammation_depression = 0.2
beta_inflammation_BM1 = 0.6
beta_inflammation_BM2 = 0.6
beta_inflammation_BM3 = 0.6
beta_inflammation_BM4 = 0.2
beta_genotype_inflammation = 0.5
beta_age_inflammation = 0.4
beta_age_depression = -0.3
beta_inflammation_fatigue = 0.3
beta_depression_fatigue = 0.6
beta_age_fatigue = 0.2
beta_pain_fatigue = 0.1
beta_inflammation_pain = 0.3
beta_pain_depression = 0.3


############################################################
########## 3. Data generation function
############################################################

generate.dataset <- function() {
	genotype = rnorm(sample_size)
	
	age = rnorm(sample_size)
	
	inflammation = genotype*beta_genotype_inflammation + age*beta_age_inflammation + rnorm(sample_size, sd=sqrt(1-(beta_genotype_inflammation^2+beta_age_inflammation^2)))
	
	pain = inflammation*beta_inflammation_pain + rnorm(sample_size, sd=sqrt(1-beta_inflammation_pain^2))
	
	depression = inflammation*beta_inflammation_depression + age*beta_age_depression + pain*beta_pain_depression + rnorm(sample_size, sd=sqrt(1-(beta_inflammation_depression^2+beta_age_depression^2+beta_pain_depression^2)))
	
	BM1 = inflammation*beta_inflammation_BM1 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM1^2))
	BM2 = inflammation*beta_inflammation_BM2 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM2^2))
	BM3 = inflammation*beta_inflammation_BM3 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM3^2))
	BM4 = inflammation*beta_inflammation_BM4 + rnorm(sample_size, sd=sqrt(1-beta_inflammation_BM4^2))
	
	fatigue = inflammation*beta_inflammation_fatigue + depression*beta_depression_fatigue + age*beta_age_fatigue + pain*beta_pain_fatigue + rnorm(sample_size, sd=sqrt(1-(beta_inflammation_fatigue^2+beta_depression_fatigue^2+beta_age_fatigue^2+beta_pain_fatigue^2)))
	
	# add extreme values to biomarker variables
	
	BM1[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM2[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM3[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)
	BM4[sample(1:sample_size, n_extreme_values)] = runif(n_extreme_values,3,6)

	return(data.frame(age, genotype, BM1, BM2, BM3, BM4, depression, pain, fatigue))
}


############################################################
########## 4. Generate and analyze the replicate samples
############################################################

median_beta_full = rep(NA, n_replicates) # median effect size 
median_beta_model1 = rep(NA, n_replicates)
median_beta_model2 = rep(NA, n_replicates)
proportion_sig_full = rep(NA, n_replicates) # proportion of p-values < .05 
proportion_sig_model1 = rep(NA, n_replicates) 
proportion_sig_model2 = rep(NA, n_replicates) 
median_p_full = rep(NA, n_replicates) # median p-value
median_p_model1 = rep(NA, n_replicates) 
median_p_model2 = rep(NA, n_replicates) 

for (sample in 1:n_replicates) {
	
	dataset = generate.dataset()
		
	##### Standard deviations and Tukey's fences (for outlier cutoffs)
	
	sd.BM1 = sd(dataset$BM1)
	sd.BM2 = sd(dataset$BM2)
	sd.BM3 = sd(dataset$BM3)
	sd.BM4 = sd(dataset$BM4)
	
	Tukey.lower.BM1 = quantile(dataset$BM1, probs=0.25)-1.5*(quantile(dataset$BM1, probs=0.75)-quantile(dataset$BM1, probs=0.25)) 
	Tukey.upper.BM1 = quantile(dataset$BM1, probs=0.75)+1.5*(quantile(dataset$BM1, probs=0.75)-quantile(dataset$BM1, probs=0.25))
	Tukey.lower.BM2 = quantile(dataset$BM2, probs=0.25)-1.5*(quantile(dataset$BM2, probs=0.75)-quantile(dataset$BM2, probs=0.25))
	Tukey.upper.BM2 = quantile(dataset$BM2, probs=0.75)+1.5*(quantile(dataset$BM2, probs=0.75)-quantile(dataset$BM2, probs=0.25))
	Tukey.lower.BM3 = quantile(dataset$BM3, probs=0.25)-1.5*(quantile(dataset$BM3, probs=0.75)-quantile(dataset$BM3, probs=0.25))
	Tukey.upper.BM3 = quantile(dataset$BM3, probs=0.75)+1.5*(quantile(dataset$BM3, probs=0.75)-quantile(dataset$BM3, probs=0.25))
	Tukey.lower.BM4 = quantile(dataset$BM4, probs=0.25)-1.5*(quantile(dataset$BM4, probs=0.75)-quantile(dataset$BM4, probs=0.25))
	Tukey.upper.BM4 = quantile(dataset$BM4, probs=0.75)+1.5*(quantile(dataset$BM4, probs=0.75)-quantile(dataset$BM4, probs=0.25))
	
	##### Calculate p-values and effect sizes (regression beta)
	
	p_values = rep(NA, 1216) # vector of p-values
	betas = rep(NA, 1216) # vector of effect sizes
	conf.low = rep(NA, 1216) # vector of lower confidence bounds
	conf.high = rep(NA, 1216) # vector of higher confidence bounds
	ns = rep(NA, 1216) # vector of sample sizes
	x = rep("", 1216) # vector of labels for alternative predictor specifications
	controls = rep("", 1216) # vector of labels for covariates
	model = rep("", 1216) # vector of labels for alternative outlier cutoffs
	
	
	index = 1 # vector location index 
	
	for (predictor in 1:19) {
		for (covariates in 1:16) {
			for (outliers in 1:4)
			{
				model_formula = "data$depression ~ data$pred"  # regression formula to be passed to lm()
				
				# decision node: alternative cutoffs for outliers
				
				if (outliers == 1) {
					data = dataset
					model[index] = "d  All cases"
					}
				else if (outliers == 2) {
					data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,]
					model[index] = "c  Quartiles +/- 1.5 IQR"
					}
				else if (outliers == 3) {
					data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
					model[index] = "b  Mean +/- 2.5 SD"
					}
				else if (outliers == 4) {
					data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
					model[index] = "a  Mean +/- 3.5 SD"
					}
				
				ns[index] = nrow(data)  # save sample size after outlier exclusion
				
				# decision node: alternative predictors
				
				if (predictor == 1) {
					data$pred = data$BM1
					x[index] = "s  Biomarker BM1"
					}
				else if (predictor == 2) {
					data$pred = data$BM2
					x[index] = "r  Biomarker BM2"
					}
				else if (predictor == 3) {
					data$pred = data$BM3
					x[index] = "q  Biomarker BM3"
					}
				else if (predictor == 4) {
					data$pred = data$BM4
					x[index] = "p  Biomarker BM4"
					}
				else if (predictor == 5) {
					data$pred = data$BM1
					x[index] = "o  BM1, other biomarkers controlled"
					model_formula = paste(model_formula, "+ data$BM2 + data$BM3 + data$BM4")
					}
				else if (predictor == 6) {
					data$pred = data$BM2
					x[index] = "n  BM2, other biomarkers controlled"
					model_formula = paste(model_formula, "+ data$BM1 + data$BM3 + data$BM4")
					}
				else if (predictor == 7) {
					data$pred = data$BM3
					x[index] = "m  BM3, other biomarkers controlled"
					model_formula = paste(model_formula, "+ data$BM1 + data$BM2 + data$BM4")
					}
				else if (predictor == 8) {
					data$pred = data$BM4
					x[index] = "l  BM4, other biomarkers controlled"
					model_formula = paste(model_formula, "+ data$BM1 + data$BM2 + data$BM3")
					}
				else if (predictor == 9) {
					data$pred = data$BM1+data$BM2
					x[index] = "k  BM1+BM2 composite"
					}
				else if (predictor == 10) {
					data$pred = data$BM1+data$BM3
					x[index] = "j  BM1+BM3 composite"
					}
				else if (predictor == 11) {
					data$pred = data$BM1+data$BM4
					x[index] = "i  BM1+BM4 composite"
					}
				else if (predictor == 12) {
					data$pred = data$BM2+data$BM3
					x[index] = "h  BM2+BM3 composite"
					}
				else if (predictor == 13) {
					data$pred = data$BM2+data$BM4
					x[index] = "g  BM2+BM4 composite"
					}
				else if (predictor == 14) {
					data$pred = data$BM3+data$BM4
					x[index] = "f  BM3+BM4 composite"
					}
				else if (predictor == 15) {
					data$pred = data$BM1+data$BM2+data$BM3
					x[index] = "e  BM1+BM2+BM3 composite"
					}
				else if (predictor == 16) {
					data$pred = data$BM1+data$BM2+data$BM4
					x[index] = "d  BM1+BM2+BM4 composite"
					}
				else if (predictor == 17) {
					data$pred = data$BM1+data$BM3+data$BM4
					x[index] = "c  BM1+BM3+BM4 composite"
					}
				else if (predictor == 18) {
					data$pred = data$BM2+data$BM3+data$BM4
					x[index] = "b  BM2+BM3+BM4 composite"
					}
				else if (predictor == 19) {
					data$pred = data$BM1+data$BM2+data$BM3+data$BM4
					x[index] = "a  BM1+BM2+BM3+BM4 composite"
					}
				
				# decision node: alternative covariate sets
				
				if (covariates == 1) {
					controls[index] = "p  No covariates"			
					}
				else if (covariates == 2) {
					model_formula = paste(model_formula, "+ data$fatigue")
					controls[index] = "m  Fatigue"
					}
				else if (covariates == 3) {
					model_formula = paste(model_formula, "+ data$pain")
					controls[index] = "n  Pain"
					}
				else if (covariates == 4) {
					model_formula = paste(model_formula, "+ data$pain + data$fatigue")
					controls[index] = "h  Pain, fatigue"
					}
				else if (covariates == 5) {
					model_formula = paste(model_formula, "+ data$age")
					controls[index] = "o  Age"
					}
				else if (covariates == 6) {
					model_formula = paste(model_formula, "+ data$fatigue + data$age")
					controls[index] = "j  Age, fatigue"
					}
				else if (covariates == 7) {
					model_formula = paste(model_formula, "+ data$pain + data$age")
					controls[index] = "k  Age, pain"
					}
				else if (covariates == 8) {
					model_formula = paste(model_formula, "+ data$fatigue + data$pain + data$age")
					controls[index] = "e  Age, pain, fatigue"
					}
				else if (covariates == 9) {
					model_formula = paste(model_formula, "+ data$genotype")
					controls[index] = "l  Genotype"
					}
				else if (covariates == 10) {
					model_formula = paste(model_formula, "+ data$genotype + data$fatigue")
					controls[index] = "f  Fatigue, genotype"
					}
				else if (covariates == 11) {
					model_formula = paste(model_formula, "+ data$genotype + data$pain")
					controls[index] = "g  Pain, genotype"
					}
				else if (covariates == 12) {
					model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$pain")
					controls[index] = "b  Pain, fatigue, genotype"
					}
				else if (covariates == 13) {
					model_formula = paste(model_formula, "+ data$genotype + data$age")
					controls[index] = "i  Age, genotype"
					}
				else if (covariates == 14) {
					model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$age")
					controls[index] = "c  Age, fatigue, genotype"
					}
				else if (covariates == 15) {
					model_formula = paste(model_formula, " + data$genotype+ data$pain + data$age")
					controls[index] = "d  Age, pain, genotype"
					}
				else if (covariates == 16) {
					model_formula = paste(model_formula, "+ data$genotype + data$fatigue + data$pain + data$age")
					controls[index] = "a  Age, pain, fatigue, genotype"
					}
				
				# regression fit
				
				standardized.model = lm.beta(lm(as.formula(model_formula)))
				
				# save beta, p-value, confidence intervals for the predictor
				
				betas[index] = summary(standardized.model)$coefficients[2,2]
				p_values[index] = summary(standardized.model)$coefficients[2,5]
				conf.low[index] = confint(standardized.model)[2,1]
				conf.high[index] = confint(standardized.model)[2,2]
				
				# increment location index for p-values and effect sizes
				
				index = index + 1
			}
		}
	}

	median_beta_full[sample] = quantile(betas, probs=0.50)
	proportion_sig_full[sample] = sum(p_values<.05)/length(p_values)
	median_p_full[sample] = quantile(p_values, probs=0.50)
	
	##### Calculate p-values and effect sizes (beta): Model 1
	
	p_values_model1 = rep(NA, 6) # vector of p-values
	betas_model1 = rep(NA, 6) # vector of effect sizes
	
	index = 1 # vector location index 
	
	for (predictor in 1:2) {
			for (outliers in 1:3)
			{
				model_formula = "data$depression ~ data$pred" # regression formula to be passed to lm()
				
				# alternative cutoffs for outliers
				
				if (outliers == 1) data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,] 
				else if (outliers == 2) data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
				else if (outliers == 3) data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
				
				# alternative predictors
				
				if (predictor == 1) data$pred = data$BM1+data$BM2+data$BM3
				else if (predictor == 2) data$pred = data$BM1+data$BM2+data$BM3+data$BM4
				
				# covariate set
				
				model_formula = paste(model_formula, "+ data$age + data$pain")
				
				# regression model
				
				standardized.model = lm.beta(lm(as.formula(model_formula)))
				
				# beta and p-value for the predictor
				
				betas_model1[index] = summary(standardized.model)$coefficients[2,2]
				p_values_model1[index] = summary(standardized.model)$coefficients[2,5]
				
				# increment location index for p-values and effect sizes
				
				index = index + 1
			}
	}
	
	median_beta_model1[sample] = quantile(betas_model1, probs=0.50)
	proportion_sig_model1[sample] = sum(p_values_model1<.05)/length(p_values_model1)
	median_p_model1[sample] = quantile(p_values_model1, probs=0.50)
	
	##### Calculate p-values and effect sizes (beta): Model 2
	
	p_values_model2 = rep(NA, 6) # vector of p-values
	betas_model2 = rep(NA, 6) # vector of effect sizes
	
	index = 1 # location index for p-values and effect sizes
	
	for (predictor in 1:2) {
			for (outliers in 1:3)
			{
				model_formula = "data$depression ~ data$pred" # regression formula to be passed to lm()
				
				# alternative cutoffs for outliers
				
				if (outliers == 1) data = dataset[dataset$BM1>=Tukey.lower.BM1 & dataset$BM1<=Tukey.upper.BM1 & dataset$BM2>=Tukey.lower.BM2 & dataset$BM2<=Tukey.upper.BM2 & dataset$BM3>=Tukey.lower.BM3 & dataset$BM3<=Tukey.upper.BM3 & dataset$BM4>=Tukey.lower.BM4 & dataset$BM4<=Tukey.upper.BM4,] 
				else if (outliers == 2) data = dataset[(abs(dataset$BM1)<=2.5*sd.BM1 & abs(dataset$BM2)<=2.5*sd.BM2 & abs(dataset$BM3)<=2.5*sd.BM3 & abs(dataset$BM4)<=2.5*sd.BM4),]
				else if (outliers == 3) data = dataset[(abs(dataset$BM1)<=3.5*sd.BM1 & abs(dataset$BM2)<=3.5*sd.BM2 & abs(dataset$BM3)<=3.5*sd.BM3 & abs(dataset$BM4)<=3.5*sd.BM4),]
				
				# alternative predictors
				
				if (predictor == 1) data$pred = data$BM1+data$BM2+data$BM3
				else if (predictor == 2) data$pred = data$BM1+data$BM2+data$BM3+data$BM4
				
				# covariate set
				
				model_formula = paste(model_formula, "+ data$age + data$pain + data$fatigue")
				
				# regression model
				
				standardized.model = lm.beta(lm(as.formula(model_formula)))
				
				# beta and p-value for the predictor
				
				betas_model2[index] = summary(standardized.model)$coefficients[2,2]
				p_values_model2[index] = summary(standardized.model)$coefficients[2,5]
				
				# increment location index for p-values and effect sizes
				
				index = index + 1
			}
	}

	median_beta_model2[sample] = quantile(betas_model2, probs=0.50)
	proportion_sig_model2[sample] = sum(p_values_model2<.05)/length(p_values_model1)
	median_p_model2[sample] = quantile(p_values_model2, probs=0.50)

print(sample)

}


############################################################
########## 5. Save results file (if desired)
############################################################

# write.csv(data.frame(median_beta_full, median_beta_model1, median_beta_model2, median_p_full, median_p_model1, median_p_model2, proportion_sig_full, proportion_sig_model1, proportion_sig_model2), file="results.csv")


############################################################
########## 6. Load results file
############################################################

replicates_results = read.csv(file="multiverse_replicate_analyses.csv")[,-1]  # file with the results presented in the article


############################################################
########## 7. Ridge plots  
##########
########## (Note: plots require additional clean-up/editing)
############################################################

beta_grouped = data.frame(median_beta = c(replicates_results$median_beta_full, replicates_results$median_beta_model1, replicates_results$median_beta_model2), analysis = c(rep("c Full multiverse",n_replicates), rep("b Model 1",n_replicates), rep("a Model 2",n_replicates)))

p_grouped = data.frame(median_p = c(replicates_results$median_p_full, replicates_results$median_p_model1, replicates_results$median_p_model2), analysis = c(rep("c Full multiverse",n_replicates), rep("b Model 1",n_replicates), rep("a Model 2",n_replicates)))

color_full = rgb(210,205,230, alpha=255, maxColorValue=255)
color_model1 = rgb(200,235,235, alpha=255, maxColorValue=255) 
color_model2 = rgb(225,245,215, alpha=255, maxColorValue=255)

quartz(width=7, height=3.7)

ggplot(data=beta_grouped, aes(y=analysis, x=median_beta,  fill=analysis)) +
    geom_density_ridges(alpha=0.75, stat="binline", bins=30, scale=0.9,  size=0.3) +
    scale_fill_cyclical(values=c(color_model2, color_model1, color_full))+
    scale_x_continuous(breaks=c(-0.2,-0.1,0, 0.1, 0.2, 0.3))+
    theme_ridges(center_axis_labels=TRUE) +
    theme(
      legend.position="none",
      panel.spacing = unit(0.1, "lines"),
      strip.text.x = element_text(size = 8)
    ) +
    xlab(expression(paste("Median effect size (", beta, ")"))) +
    ylab("Frequency")
    
quartz(width=7, height=3.7)

ggplot(data=p_grouped, aes(y=analysis, x=median_p,  fill=analysis)) +
    geom_density_ridges(alpha=0.75, stat="binline", bins=30, scale=0.9,  size=0.3) +
    scale_fill_cyclical(values=c(color_model2, color_model1, color_full))+
    scale_x_continuous(breaks=c(0,0.2,0.40,0.60, 0.80, 1.00))+
    theme_ridges(center_axis_labels=TRUE) +
    theme(
      legend.position="none",
      panel.spacing = unit(0.1, "lines"),
      strip.text.x = element_text(size = 8)
    ) +
    xlab(expression(paste("Median ", italic(p),"-value"))) +
    ylab("Frequency")+
    geom_vline(xintercept=0.05, colour="red", linetype="dashed", size=0.35)+
    annotate("text", x=0.12, y=3.5, label=expression(paste(italic(p)," = .05")), colour="red", size=4.2)


